==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Select/SelectLayerByEntity/ts/SelectLayerByEntity_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>SelectLayerByEntity</name>
    <message>
        <location filename="../SelectLayerByEntity.js" line="+68"/>
        <source>Choose entity on layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SelectLayerByEntity.ui" line="+17"/>
        <source>Mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Replace the current selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <location line="+20"/>
        <location line="+20"/>
        <location line="+20"/>
        <source>SelectionMode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-53"/>
        <source>Add to the current selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Subtract from the current selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Intersect with the current selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SelectLayerByEntityInit.js" line="+2"/>
        <source>(De-)Select La&amp;yer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>(De-)Select all entities on the same layer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Select/SelectLayerByEntity/ts/SelectLayerByEntity_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>SelectLayerByEntity</name>
    <message>
        <location filename="../SelectLayerByEntity.js" line="+68"/>
        <source>Choose entity on layer</source>
        <translation>Vyberte objekt na vrstvě</translation>
    </message>
    <message>
        <location filename="../SelectLayerByEntity.ui" line="+17"/>
        <source>Mode:</source>
        <translation>Režim:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Replace the current selection</source>
        <translation>Nahradit aktuální výběr</translation>
    </message>
    <message>
        <location line="+16"/>
        <location line="+20"/>
        <location line="+20"/>
        <location line="+20"/>
        <source>SelectionMode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-53"/>
        <source>Add to the current selection</source>
        <translation>Přidat k aktuálnímu výběru</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Subtract from the current selection</source>
        <translation>Ubrat z aktuálního výběru</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Intersect with the current selection</source>
        <translation>Průnik s aktuálním výběrem</translation>
    </message>
    <message>
        <location filename="../SelectLayerByEntityInit.js" line="+2"/>
        <source>(De-)Select La&amp;yer</source>
        <translation>(Ne-)Vybrat &amp;vrstvu</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>(De-)Select all entities on the same layer</source>
        <translation>(Ne-)Vybrat všechny objekty na stejné &amp;vrstvě</translation>
    </message>
</context>
</TS>
